==> v0.7.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/xcontent/BoolFilterBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.xcontent;

import org.apache.lucene.search.BooleanClause;
import org.elasticsearch.util.xcontent.builder.XContentBuilder;

import java.io.IOException;
import java.util.ArrayList;

/**
 * A filter that matches documents matching boolean combinations of other filters.
 *
 * @author kimchy (shay.banon)
 */
public class BoolFilterBuilder extends BaseFilterBuilder {

    private ArrayList<Clause> clauses = new ArrayList<Clause>();

    /**
     * Adds a filter that <b>must</b> appear in the matching documents.
     */
    public BoolFilterBuilder must(XContentFilterBuilder filterBuilder) {
        clauses.add(new Clause(filterBuilder, BooleanClause.Occur.MUST));
        return this;
    }

    /**
     * Adds a filter that <b>must not</b> appear in the matching documents.
     */
    public BoolFilterBuilder mustNot(XContentFilterBuilder filterBuilder) {
        clauses.add(new Clause(filterBuilder, BooleanClause.Occur.MUST_NOT));
        return this;
    }

    /**
     * Adds a filter that <i>should</i> appear in the matching documents. For a boolean filter
     * with no <tt>MUST</tt> clauses one or more <code>SHOULD</code> clauses must match a document
     * for the BooleanQuery to match.
     */
    public BoolFilterBuilder should(XContentFilterBuilder filterBuilder) {
        clauses.add(new Clause(filterBuilder, BooleanClause.Occur.SHOULD));
        return this;
    }

    @Override protected void doXContent(XContentBuilder builder, Params params) throws IOException {
        builder.startObject("bool");
        for (Clause clause : clauses) {
            if (clause.occur == BooleanClause.Occur.MUST) {
                builder.field("must");
                clause.filterBuilder.toXContent(builder, params);
            } else if (clause.occur == BooleanClause.Occur.MUST_NOT) {
                builder.field("must_not");
                clause.filterBuilder.toXContent(builder, params);
            } else if (clause.occur == BooleanClause.Occur.SHOULD) {
                builder.field("should");
                clause.filterBuilder.toXContent(builder, params);
            }
        }
        builder.endObject();
    }

    private static class Clause {
        final XContentFilterBuilder filterBuilder;
        final BooleanClause.Occur occur;

        private Clause(XContentFilterBuilder filterBuilder, BooleanClause.Occur occur) {
            this.filterBuilder = filterBuilder;
            this.occur = occur;
        }
    }
}

==> v0.9.0.zip: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/index/query/xcontent/BoolFilterBuilder.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.index.query.xcontent;

import org.apache.lucene.search.BooleanClause;
import org.elasticsearch.common.xcontent.builder.XContentBuilder;

import java.io.IOException;
import java.util.ArrayList;

/**
 * A filter that matches documents matching boolean combinations of other filters.
 *
 * @author kimchy (shay.banon)
 */
public class BoolFilterBuilder extends BaseFilterBuilder {

    private ArrayList<Clause> clauses = new ArrayList<Clause>();

    /**
     * Adds a filter that <b>must</b> appear in the matching documents.
     */
    public BoolFilterBuilder must(XContentFilterBuilder filterBuilder) {
        clauses.add(new Clause(filterBuilder, BooleanClause.Occur.MUST));
        return this;
    }

    /**
     * Adds a filter that <b>must not</b> appear in the matching documents.
     */
    public BoolFilterBuilder mustNot(XContentFilterBuilder filterBuilder) {
        clauses.add(new Clause(filterBuilder, BooleanClause.Occur.MUST_NOT));
        return this;
    }

    /**
     * Adds a filter that <i>should</i> appear in the matching documents. For a boolean filter
     * with no <tt>MUST</tt> clauses one or more <code>SHOULD</code> clauses must match a document
     * for the BooleanQuery to match.
     */
    public BoolFilterBuilder should(XContentFilterBuilder filterBuilder) {
        clauses.add(new Clause(filterBuilder, BooleanClause.Occur.SHOULD));
        return this;
    }

    @Override protected void doXContent(XContentBuilder builder, Params params) throws IOException {
        builder.startObject("bool");
        for (Clause clause : clauses) {
            if (clause.occur == BooleanClause.Occur.MUST) {
                builder.field("must");
                clause.filterBuilder.toXContent(builder, params);
            } else if (clause.occur == BooleanClause.Occur.MUST_NOT) {
                builder.field("must_not");
                clause.filterBuilder.toXContent(builder, params);
            } else if (clause.occur == BooleanClause.Occur.SHOULD) {
                builder.field("should");
                clause.filterBuilder.toXContent(builder, params);
            }
        }
        builder.endObject();
    }

    private static class Clause {
        final XContentFilterBuilder filterBuilder;
        final BooleanClause.Occur occur;

        private Clause(XContentFilterBuilder filterBuilder, BooleanClause.Occur occur) {
            this.filterBuilder = filterBuilder;
            this.occur = occur;
        }
    }
}
